Welcome to Grascii's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   language
   gsearch
   dictionary
   configuration
   similarity
   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
